@@ -89,6 +89,7 @@ sgd <- function(init,fitfunc,whichignore=c(),nsubsets=1,nsubjects=NA,ndatapoints
     while(!accepted){
       notacceptedcount <- notacceptedcount+1
       if(notacceptedcount > 20) {
+        browser()
         stop('Cannot optimize! Problematic model, or bug?')
         print(lpg)
       }
@@ -183,9 +184,9 @@ sgd <- function(init,fitfunc,whichignore=c(),nsubsets=1,nsubjects=NA,ndatapoints
       } 
       if(!accepted){
         #if(nsubsets==1) gsmooth= gsmooth*gmemory2^2 + (1-gmemory2^2) * g #increase influence of last gradient at inflections
-        step <- step * .5
+        step <- step / (exp(notacceptedcount))
         deltaold <- deltaold * 0
-        if(nsubsets > 1) pars =bestpars* .8 + apply(parstore,2,mean)*.2
+        if(nsubsets > 1) pars =bestpars* .8 + apply(parstore,1,mean)*.2
         # if(i > 1) lproughness = lproughness * (roughnessmemory2) + (1-(roughnessmemory2)) ##exp(-1/(i-bestiter+.1))
         # pars=bestpars
       }
